// $Id: MidiOutDevice.cc,v 1.8 2005/11/15 20:03:46 m9710797 Exp $

#include "MidiOutDevice.hh"

namespace openmsx {

MidiOutDevice::~MidiOutDevice()
{
}

const std::string& MidiOutDevice::getClass() const
{
	static const std::string className("midi out");
	return className;
}


void MidiOutDevice::setDataBits(DataBits /*bits*/)
{
	// ignore
}

void MidiOutDevice::setStopBits(StopBits /*bits*/)
{
	// ignore
}

void MidiOutDevice::setParityBit(bool /*enable*/, ParityBit /*parity*/)
{
	// ignore
}

} // namespace openmsx
